#!/bin/sh

TMPFILE=/tmp/ga.batch.tmp
POP_SIZE=100
ASGA_SIZE="0 25 50 75 100"
GENERATIONS=300
NR_TESTS=20
NICE=19


BIN=`dirname $0`

# rm -rf result || true
mkdir result || true

# Prepare gnuplot files

echo 'set size ratio 0.8 0.6' >result/avg.gnu
echo 'set term postscript eps enhanced' >>result/avg.gnu
echo "set output 'result/avg.eps'" >>result/avg.gnu
echo -n 'plot ' >>result/avg.gnu

echo 'set term postscript eps color solid "Time-Roman" 18' >result/best.gnu
echo "set output 'result/best.eps'" >>result/best.gnu
echo -n 'plot ' >>result/best.gnu

echo 'set term postscript eps color solid "Time-Roman" 18' >result/dev.gnu
echo "set output 'result/dev.eps'" >>result/dev.gnu
echo -n 'plot ' >>result/dev.gnu

for asga in ${ASGA_SIZE} ; do
   ga=`expr ${POP_SIZE} - $asga`
   AVGFILE=result/result.avg.ga${ga}.asga${asga}.dat
   BESTFILE=result/result.best.ga${ga}.asga${asga}.dat
   STDDEVFILE=result/result.dev.ga${ga}.asga${asga}.dat
 
   touch $AVGFILE
   touch $BESTFILE
   touch $STDDEVFILE
 
   for i in `seq -w $NR_TESTS` ; do
      OUTFILE=result/result.$i.ga${ga}.asga${asga}.dat
      echo -n "$i.Test ga${ga} asga${asga} "
      if [ ! -e $OUTFILE ] ; then
              echo Running 
	      nice -n $NICE ${BIN}/run.sh $ga $asga $GENERATIONS >$OUTFILE
      else
              echo Skipping 
      fi
     
      # Extend sum for average file
      # Average value is second row in data file. Then, put brackets around
      # the value and append each line to the already existing avgfile
      # connected by a + sign. Thus, we should get the sum of values that
      # we can pipe to bc in the end.
      cut -f "2" $OUTFILE | sed -e "s/.*E.*/0/g" | sed -e "s/^\(.*\)$/(\1)/" | paste -d "+" $AVGFILE - >$TMPFILE
      mv $TMPFILE $AVGFILE
      
      # Extend sum for stddev file
      cut -f "3" $OUTFILE | sed -e "s/.*E.*/0/g" | sed -e "s/^\(.*\)$/(\1)/" | paste -d "+" $STDDEVFILE - >$TMPFILE
      mv $TMPFILE $STDDEVFILE
      
      # Extend sum for best file
      cut -f "1" $OUTFILE | sed -e "s/.*E.*/0/g" | sed -e "s/^\(.*\)$/(\1)/" | paste -d "+" $BESTFILE - >$TMPFILE
      mv $TMPFILE $BESTFILE
   done
   
   # There is a + sign at the beginning of each line now, which will cause
   # trouble. Create the formular for the average value via sed.
   sed -e "s,^+\(.*\)$,(\1)/$NR_TESTS,g" $AVGFILE | bc |cat -n >$AVGFILE.val

   # add file to gnuplot file
   echo -n " '$AVGFILE.val' title 'ga=$ga asga=$asga' with lines," >>result/avg.gnu
  
   sed -e "s,^+\(.*\)$,(\1)/$NR_TESTS,g" $BESTFILE | bc |cat -n >$BESTFILE.val
   echo -n " '$BESTFILE.val' title 'ga=$ga asga=$asga' with lines," >>result/best.gnu
   
   sed -e "s,^+\(.*\)$,(\1)/$NR_TESTS,g" $STDDEVFILE | bc | cat -n >$STDDEVFILE.val
   echo -n " '$STDDEVFILE.val' title 'ga=$ga asga=$asga' with lines," >>result/dev.gnu
   
done

echo >>result/avg.gnu
echo >>result/best.gnu
echo >>result/dev.gnu

# Remove comas from end of gnuplot lines 
sed -e "s/,$//" result/avg.gnu >$TMPFILE
mv $TMPFILE result/avg.gnu
sed -e "s/,$//" result/best.gnu >$TMPFILE
mv $TMPFILE result/best.gnu
sed -e "s/,$//" result/dev.gnu >$TMPFILE
mv $TMPFILE result/dev.gnu

# Create diagrams
gnuplot result/avg.gnu
gnuplot result/best.gnu
gnuplot result/dev.gnu

