/**
 * File information:
 * $Author: nmk148 $
 * First check-in: $Date: 2003/03/23 17:20:10 $
 * $Revision: 1.2 $
 *
 * A problem specification for the GA Framework. Classes implementing this
 * interface have to implement a method that returns the size of the genome
 * and a method that computes the fitness of a genome.
 **/
public interface Problem {

	
	/**
	 * Returns the required size of the genome
	 * @return required size of genome
	 **/
	public int geneSize();

	/**
	 * Given a genome, this function computes the fitness
	 * of the individual, according the the problem.
	 * @param gene the genome
	 * @return a fitness value
	 **/
	public double fitness(boolean[] gene);


	/**
	 * Returns a string that contains a readable version
	 * of the solution the an individual actually represents.
	 * @param ind the individual
	 * @return a string for <b>ind</b>
	 **/
	public String toString(boolean[] gene);
	
}


/* Put java code here */

/*
 * History of this file:
 * $Log: Problem.java,v $
 * Revision 1.2  2003/03/23 17:20:10  nmk148
 * Added toString...
 *
 * Revision 1.1  2003/03/17 07:35:04  nmk148
 * First checkin
 *
 */
