import java.io.*;
import java.util.*;

/**
 * File information:<br>
 * $Author: nmk148 $<br>
 * First check-in: $Date: 2003/03/24 04:40:29 $<br>
 * $Revision: 1.2 $<br>
 * <br>
 *
 **/

public class TSPProblemFactory {

	/**
	 * Reads a set of (x,y)-pairs from a file and 
	 * creates an instance of TSPProblem from it.
	 **/
	public static TSPProblem createPlanarTSP(String fileName) 
		throws IOException {

		double[] x = new double[1000];
		double[] y = new double[1000];
		int n = 0;

		BufferedReader r = 
			new BufferedReader(new FileReader(fileName));

		/* Read all lines into x and y */
		String line = r.readLine().trim();
		while (line != null) {
			if ("".equals(line) || line.startsWith("#")) {
			} else {
				StringTokenizer t;
				double tmp;
				
				t = new StringTokenizer(line);
				x[n] = Double.parseDouble(t.nextToken());
				y[n] = Double.parseDouble(t.nextToken());
				n++;
			}	
			line = r.readLine();
		}

		/* Compute adjacency matrix */
		double[][] dist = new double[n][n];
		for (int i=0; i<n; i++) {
			for (int j=0; j<n; j++) {
				dist[i][j] = dist(x[i],y[i],x[j],y[j]);
			}
		}

		/* Create TSPProblem */
		TSPProblem p = new TSPProblem(dist);
	
		return p;
		
	}

	private static double dist(double x1, double y1, 
		                   double x2, double y2) {

		return Math.sqrt((x1-x2)*(x1-x2) + (y1-y2)*(y1-y2));
		
	}

			
}

/*
 * History of this file:
 * $Log: TSPProblemFactory.java,v $
 * Revision 1.2  2003/03/24 04:40:29  nmk148
 * Replaced GAIndividual and GAPopulation by Individual and Population
 *
 * Revision 1.1  2003/03/23 17:21:26  nmk148
 * First checkin
 *
 */
